@@ -10,11 +10,155 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, TagManager as _TagManager_2508893f, Resource as _Resource_884d0774, Size as _Size_b4ccfc18, RemovalPolicy as _RemovalPolicy_5986e9f3, IResource as _IResource_72f7ee7e)
+from .. import (Resource as _Resource_884d0774, Construct as _Construct_f50a3f53, CfnResource as _CfnResource_7760e8e4, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, TagManager as _TagManager_2508893f, Size as _Size_b4ccfc18, RemovalPolicy as _RemovalPolicy_5986e9f3, IResource as _IResource_72f7ee7e)
 from ..aws_ec2 import (Connections as _Connections_231f38b5, ISecurityGroup as _ISecurityGroup_d72ab8e8, IVpc as _IVpc_3795853f, SubnetSelection as _SubnetSelection_36a13cd6, IConnectable as _IConnectable_a587039f)
 from ..aws_kms import (IKey as _IKey_3336c79d)
 
 
+@jsii.data_type(jsii_type="monocdk-experiment.aws_efs.AccessPointProps", jsii_struct_bases=[], name_mapping={'file_system': 'fileSystem', 'create_acl': 'createAcl', 'path': 'path', 'posix_user': 'posixUser'})
+class AccessPointProps():
+    def __init__(self, *, file_system: "IFileSystem", create_acl: typing.Optional["Acl"]=None, path: typing.Optional[str]=None, posix_user: typing.Optional["PosixUser"]=None) -> None:
+        """Properties for the AccessPoint.
+
+        :param file_system: The efs filesystem.
+        :param create_acl: Specifies the POSIX IDs and permissions to apply when creating the access point's root directory. If the root directory specified by ``path`` does not exist, EFS creates the root directory and applies the permissions specified here. If the specified ``path`` does not exist, you must specify ``createAcl``. Default: - None. The directory specified by ``path`` must exist.
+        :param path: Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system. Default: '/'
+        :param posix_user: The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point. Specify this to enforce a user identity using an access point. Default: - user identity not enforced
+
+        stability
+        :stability: experimental
+        """
+        if isinstance(create_acl, dict): create_acl = Acl(**create_acl)
+        if isinstance(posix_user, dict): posix_user = PosixUser(**posix_user)
+        self._values = {
+            'file_system': file_system,
+        }
+        if create_acl is not None: self._values["create_acl"] = create_acl
+        if path is not None: self._values["path"] = path
+        if posix_user is not None: self._values["posix_user"] = posix_user
+
+    @builtins.property
+    def file_system(self) -> "IFileSystem":
+        """The efs filesystem.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('file_system')
+
+    @builtins.property
+    def create_acl(self) -> typing.Optional["Acl"]:
+        """Specifies the POSIX IDs and permissions to apply when creating the access point's root directory.
+
+        If the
+        root directory specified by ``path`` does not exist, EFS creates the root directory and applies the
+        permissions specified here. If the specified ``path`` does not exist, you must specify ``createAcl``.
+
+        default
+        :default: - None. The directory specified by ``path`` must exist.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('create_acl')
+
+    @builtins.property
+    def path(self) -> typing.Optional[str]:
+        """Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system.
+
+        default
+        :default: '/'
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('path')
+
+    @builtins.property
+    def posix_user(self) -> typing.Optional["PosixUser"]:
+        """The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point.
+
+        Specify this to enforce a user identity using an access point.
+
+        default
+        :default: - user identity not enforced
+
+        see
+        :see: - `Enforcing a User Identity Using an Access Point <https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html>`_
+        stability
+        :stability: experimental
+        """
+        return self._values.get('posix_user')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'AccessPointProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+@jsii.data_type(jsii_type="monocdk-experiment.aws_efs.Acl", jsii_struct_bases=[], name_mapping={'owner_gid': 'ownerGid', 'owner_uid': 'ownerUid', 'permissions': 'permissions'})
+class Acl():
+    def __init__(self, *, owner_gid: str, owner_uid: str, permissions: str) -> None:
+        """Permissions as POSIX ACL.
+
+        :param owner_gid: Specifies the POSIX group ID to apply to the RootDirectory. Accepts values from 0 to 2^32 (4294967295).
+        :param owner_uid: Specifies the POSIX user ID to apply to the RootDirectory. Accepts values from 0 to 2^32 (4294967295).
+        :param permissions: Specifies the POSIX permissions to apply to the RootDirectory, in the format of an octal number representing the file's mode bits.
+
+        stability
+        :stability: experimental
+        """
+        self._values = {
+            'owner_gid': owner_gid,
+            'owner_uid': owner_uid,
+            'permissions': permissions,
+        }
+
+    @builtins.property
+    def owner_gid(self) -> str:
+        """Specifies the POSIX group ID to apply to the RootDirectory.
+
+        Accepts values from 0 to 2^32 (4294967295).
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('owner_gid')
+
+    @builtins.property
+    def owner_uid(self) -> str:
+        """Specifies the POSIX user ID to apply to the RootDirectory.
+
+        Accepts values from 0 to 2^32 (4294967295).
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('owner_uid')
+
+    @builtins.property
+    def permissions(self) -> str:
+        """Specifies the POSIX permissions to apply to the RootDirectory, in the format of an octal number representing the file's mode bits.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('permissions')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'Acl(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.implements(_IInspectable_051e6ed8)
 class CfnAccessPoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_efs.CfnAccessPoint"):
     """A CloudFormation ``AWS::EFS::AccessPoint``.
@@ -1253,6 +1397,74 @@ class FileSystemProps():
         return 'FileSystemProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.interface(jsii_type="monocdk-experiment.aws_efs.IAccessPoint")
+class IAccessPoint(_IResource_72f7ee7e, jsii.compat.Protocol):
+    """Represents an EFS AccessPoint.
+
+    stability
+    :stability: experimental
+    """
+    @builtins.staticmethod
+    def __jsii_proxy_class__():
+        return _IAccessPointProxy
+
+    @builtins.property
+    @jsii.member(jsii_name="accessPointArn")
+    def access_point_arn(self) -> str:
+        """The ARN of the AccessPoint.
+
+        stability
+        :stability: experimental
+        attribute:
+        :attribute:: true
+        """
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="accessPointId")
+    def access_point_id(self) -> str:
+        """The ID of the AccessPoint.
+
+        stability
+        :stability: experimental
+        attribute:
+        :attribute:: true
+        """
+        ...
+
+
+class _IAccessPointProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+    """Represents an EFS AccessPoint.
+
+    stability
+    :stability: experimental
+    """
+    __jsii_type__ = "monocdk-experiment.aws_efs.IAccessPoint"
+    @builtins.property
+    @jsii.member(jsii_name="accessPointArn")
+    def access_point_arn(self) -> str:
+        """The ARN of the AccessPoint.
+
+        stability
+        :stability: experimental
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "accessPointArn")
+
+    @builtins.property
+    @jsii.member(jsii_name="accessPointId")
+    def access_point_id(self) -> str:
+        """The ID of the AccessPoint.
+
+        stability
+        :stability: experimental
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "accessPointId")
+
+
 @jsii.interface(jsii_type="monocdk-experiment.aws_efs.IFileSystem")
 class IFileSystem(_IConnectable_a587039f, _IResource_72f7ee7e, jsii.compat.Protocol):
     """Interface to implement AWS File Systems.
@@ -1359,6 +1571,64 @@ class PerformanceMode(enum.Enum):
     :stability: experimental
     """
 
+@jsii.data_type(jsii_type="monocdk-experiment.aws_efs.PosixUser", jsii_struct_bases=[], name_mapping={'gid': 'gid', 'uid': 'uid', 'secondary_gids': 'secondaryGids'})
+class PosixUser():
+    def __init__(self, *, gid: str, uid: str, secondary_gids: typing.Optional[typing.List[str]]=None) -> None:
+        """Represents the PosixUser.
+
+        :param gid: The POSIX group ID used for all file system operations using this access point.
+        :param uid: The POSIX user ID used for all file system operations using this access point.
+        :param secondary_gids: Secondary POSIX group IDs used for all file system operations using this access point. Default: - None
+
+        stability
+        :stability: experimental
+        """
+        self._values = {
+            'gid': gid,
+            'uid': uid,
+        }
+        if secondary_gids is not None: self._values["secondary_gids"] = secondary_gids
+
+    @builtins.property
+    def gid(self) -> str:
+        """The POSIX group ID used for all file system operations using this access point.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('gid')
+
+    @builtins.property
+    def uid(self) -> str:
+        """The POSIX user ID used for all file system operations using this access point.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('uid')
+
+    @builtins.property
+    def secondary_gids(self) -> typing.Optional[typing.List[str]]:
+        """Secondary POSIX group IDs used for all file system operations using this access point.
+
+        default
+        :default: - None
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('secondary_gids')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'PosixUser(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.enum(jsii_type="monocdk-experiment.aws_efs.ThroughputMode")
 class ThroughputMode(enum.Enum):
     """EFS Throughput mode.
@@ -1381,6 +1651,68 @@ class ThroughputMode(enum.Enum):
     :stability: experimental
     """
 
+@jsii.implements(IAccessPoint)
+class AccessPoint(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_efs.AccessPoint"):
+    """Represents the AccessPoint.
+
+    stability
+    :stability: experimental
+    """
+    def __init__(self, scope: _Construct_f50a3f53, id: str, *, file_system: "IFileSystem", create_acl: typing.Optional["Acl"]=None, path: typing.Optional[str]=None, posix_user: typing.Optional["PosixUser"]=None) -> None:
+        """
+        :param scope: -
+        :param id: -
+        :param file_system: The efs filesystem.
+        :param create_acl: Specifies the POSIX IDs and permissions to apply when creating the access point's root directory. If the root directory specified by ``path`` does not exist, EFS creates the root directory and applies the permissions specified here. If the specified ``path`` does not exist, you must specify ``createAcl``. Default: - None. The directory specified by ``path`` must exist.
+        :param path: Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system. Default: '/'
+        :param posix_user: The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point. Specify this to enforce a user identity using an access point. Default: - user identity not enforced
+
+        stability
+        :stability: experimental
+        """
+        props = AccessPointProps(file_system=file_system, create_acl=create_acl, path=path, posix_user=posix_user)
+
+        jsii.create(AccessPoint, self, [scope, id, props])
+
+    @jsii.member(jsii_name="fromAccessPointId")
+    @builtins.classmethod
+    def from_access_point_id(cls, scope: _Construct_f50a3f53, id: str, access_point_id: str) -> "IAccessPoint":
+        """Import an existing Access Point.
+
+        :param scope: -
+        :param id: -
+        :param access_point_id: -
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromAccessPointId", [scope, id, access_point_id])
+
+    @builtins.property
+    @jsii.member(jsii_name="accessPointArn")
+    def access_point_arn(self) -> str:
+        """The ARN of the Access Point.
+
+        stability
+        :stability: experimental
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "accessPointArn")
+
+    @builtins.property
+    @jsii.member(jsii_name="accessPointId")
+    def access_point_id(self) -> str:
+        """The ID of the Access Point.
+
+        stability
+        :stability: experimental
+        attribute:
+        :attribute:: true
+        """
+        return jsii.get(self, "accessPointId")
+
+
 @jsii.implements(IFileSystem)
 class FileSystem(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_efs.FileSystem"):
     """The Elastic File System implementation of IFileSystem.
@@ -1461,6 +1793,9 @@ class FileSystem(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk
 
 
 __all__ = [
+    "AccessPoint",
+    "AccessPointProps",
+    "Acl",
     "CfnAccessPoint",
     "CfnAccessPointProps",
     "CfnFileSystem",
@@ -1470,9 +1805,11 @@ __all__ = [
     "FileSystem",
     "FileSystemAttributes",
     "FileSystemProps",
+    "IAccessPoint",
     "IFileSystem",
     "LifecyclePolicy",
     "PerformanceMode",
+    "PosixUser",
     "ThroughputMode",
 ]
 
