@@ -10,7 +10,7 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnElement as _CfnElement_54343cf1, Construct as _Construct_f50a3f53, CfnCondition as _CfnCondition_548166d0, CfnResource as _CfnResource_7760e8e4)
+from .. import (CfnElement as _CfnElement_54343cf1, Construct as _Construct_f50a3f53, CfnCondition as _CfnCondition_548166d0, CfnParameter as _CfnParameter_90f1d0df, CfnResource as _CfnResource_7760e8e4)
 
 
 class CfnInclude(_CfnElement_54343cf1, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.cloudformation_include.CfnInclude"):
@@ -37,7 +37,7 @@ class CfnInclude(_CfnElement_54343cf1, metaclass=jsii.JSIIMeta, jsii_type="monoc
 
     @jsii.member(jsii_name="getCondition")
     def get_condition(self, condition_name: str) -> _CfnCondition_548166d0:
-        """Returns the CfnCondition object from the 'Conditions' section of the CloudFormation template with the give name.
+        """Returns the CfnCondition object from the 'Conditions' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
 
@@ -51,6 +51,20 @@ class CfnInclude(_CfnElement_54343cf1, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         return jsii.invoke(self, "getCondition", [condition_name])
 
+    @jsii.member(jsii_name="getParameter")
+    def get_parameter(self, parameter_name: str) -> _CfnParameter_90f1d0df:
+        """Returns the CfnParameter object from the 'Parameters' section of the included template Any modifications performed on that object will be reflected in the resulting CDK template.
+
+        If a Parameter with the given name is not present in the template,
+        throws an exception.
+
+        :param parameter_name: the name of the parameter to retrieve.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "getParameter", [parameter_name])
+
     @jsii.member(jsii_name="getResource")
     def get_resource(self, logical_id: str) -> _CfnResource_7760e8e4:
         """Returns the low-level CfnResource from the template with the given logical ID.
